@@ -1,6 +1,6 @@
 import pandas as pd
 import pytest
-
+import numpy as np
 from hieroskopia import InferDatetime
 
 
@@ -32,13 +32,14 @@ class TestDateAnalyser:
         Boundary Values:
         """
         self.date_analyser_unittest(
-            expected_list=[{'formats': expected, 'type': 'datetime'}, {}, {}, {}], data={
+            expected_list=[{'formats': expected, 'type': 'datetime'}, {}, {}, {},{}], data={
                 "date": ["2019-11-27",
                          "2019/11/28",
                          "2018-11-08"],
                 "gateway": ["PROSA", "PROSA", "PROSA"],
                 "amount": ["$4591", "$4592", "$4593"],
-                "order_id": [767313628196, 767313628196, 767313628196]
+                "order_id": [767313628196, 767313628196, 767313628196],
+                "nan": [np.nan, np.nan, np.nan]
             }, return_format=return_formats)
 
     @pytest.mark.parametrize('return_formats, expected',
@@ -51,11 +52,12 @@ class TestDateAnalyser:
         Boundary Values:
         """
         self.date_analyser_unittest(
-            expected_list=[{'formats': expected, 'type': 'datetime'}, {}, {}, {}], data={
+            expected_list=[{'formats': expected, 'type': 'datetime'}, {}, {}, {},{}], data={
                 "date": ["2019-11-27 12:00:00",
                          "2019/11/28 12:00:00",
                          "2018-11-08 12:00:00"],
                 "gateway": ["PROSA", "PROSA", "PROSA"],
                 "amount": ["$4591", "$4592", "$4593"],
-                "order_id": [767313628196, 767313628196, 767313628196]
+                "order_id": [767313628196, 767313628196, 767313628196],
+                "nan": [np.nan, np.nan, np.nan]
             }, return_format=return_formats)
